Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1043)

Unified Diff: chrome/browser/browsing_data/browsing_data_remover.h

Issue 1329083002: Clear webapp storage when site data is cleared (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Add initial tests and fix compile Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/browsing_data/browsing_data_remover.h
diff --git a/chrome/browser/browsing_data/browsing_data_remover.h b/chrome/browser/browsing_data/browsing_data_remover.h
index 0333d9fe2762e0d9be5661b4489e6b53842ef0af..09384310b27fdbdf63728342a69f877bb38664b3 100644
--- a/chrome/browser/browsing_data/browsing_data_remover.h
+++ b/chrome/browser/browsing_data/browsing_data_remover.h
@@ -82,13 +82,15 @@ class BrowsingDataRemover
REMOVE_NOCHECKS = 1 << 16,
REMOVE_WEBRTC_IDENTITY = 1 << 17,
REMOVE_CACHE_STORAGE = 1 << 18,
+ REMOVE_WEBAPP_DATA = 1 << 19,
// The following flag is used only in tests. In normal usage, hosted app
// data is controlled by the REMOVE_COOKIES flag, applied to the
// protected-web origin.
REMOVE_HOSTED_APP_DATA_TESTONLY = 1 << 31,
// "Site data" includes cookies, appcache, file systems, indexedDBs, local
// storage, webSQL, service workers, cache storage, and plugin data.
REMOVE_SITE_DATA = REMOVE_APPCACHE | REMOVE_COOKIES | REMOVE_FILE_SYSTEMS |
REMOVE_INDEXEDDB |
REMOVE_LOCAL_STORAGE |
@@ -98,7 +100,8 @@ class BrowsingDataRemover
REMOVE_WEBSQL |
REMOVE_CHANNEL_IDS |
REMOVE_SITE_USAGE_DATA |
- REMOVE_WEBRTC_IDENTITY,
+ REMOVE_WEBRTC_IDENTITY |
+ REMOVE_WEBAPP_DATA,
// Includes all the available remove options. Meant to be used by clients
// that wish to wipe as much data as possible from a Profile, to make it
@@ -386,6 +389,9 @@ class BrowsingDataRemover
#if defined(OS_ANDROID)
// Callback on UI thread when the precache history has been cleared.
void OnClearedPrecacheHistory();
+
+ // Callback on UI thread when the webapp data has been cleared.
+ void OnClearedWebappData();
#endif
void OnClearedDomainReliabilityMonitor();
@@ -446,6 +452,7 @@ class BrowsingDataRemover
bool waiting_for_clear_pnacl_cache_ = false;
#if defined(OS_ANDROID)
bool waiting_for_clear_precache_history_ = false;
+ bool waiting_for_clear_webapp_data_ = false;
#endif
bool waiting_for_clear_storage_partition_data_ = false;
#if defined(ENABLE_WEBRTC)
@@ -82,13 +82,15 @@ class BrowsingDataRemover
REMOVE_HOSTED_APP_DATA_TESTONLY = 1 << 31,
// "Site data" includes cookies, appcache, file systems, indexedDBs, local
- // storage, webSQL, service workers, cache storage, and plugin data.
+ // storage, webSQL, service workers, cache storage, plugin data, and webapp
+ // data.
REMOVE_SITE_DATA = REMOVE_APPCACHE | REMOVE_COOKIES | REMOVE_FILE_SYSTEMS |
REMOVE_INDEXEDDB |

Powered by Google App Engine
This is Rietveld 408576698